summaryrefslogtreecommitdiff
path: root/distrib/sparc/floppies/inst
diff options
context:
space:
mode:
authorNiklas Hallqvist <niklas@cvs.openbsd.org>1996-04-25 21:32:17 +0000
committerNiklas Hallqvist <niklas@cvs.openbsd.org>1996-04-25 21:32:17 +0000
commitca20eee8a154b2ffc9df0940a63371bcd284aaed (patch)
tree2be4056cd94f078774d7c965c865f62e5289467a /distrib/sparc/floppies/inst
parentd44dfb5d692e3c38d987ca775af156909295c7b3 (diff)
Did some s/NetBSD/OpenBSD/, s/netbsd/bsd/ and $OpenBSD$ additions.
However this stuff is largely related to NetBSD and must be completely redone, if we will make real relases sometime
Diffstat (limited to 'distrib/sparc/floppies/inst')
-rw-r--r--distrib/sparc/floppies/inst/dot.hdprofile5
-rw-r--r--distrib/sparc/floppies/inst/dot.instutils7
-rw-r--r--distrib/sparc/floppies/inst/install.sh33
3 files changed, 21 insertions, 24 deletions
diff --git a/distrib/sparc/floppies/inst/dot.hdprofile b/distrib/sparc/floppies/inst/dot.hdprofile
index f434c09abdd..20ef27690dc 100644
--- a/distrib/sparc/floppies/inst/dot.hdprofile
+++ b/distrib/sparc/floppies/inst/dot.hdprofile
@@ -1,3 +1,4 @@
+# $OpenBSD: dot.hdprofile,v 1.2 1996/04/25 21:31:12 niklas Exp $
#
# Copyright (c) 1994 Christopher G. Demetriou
# All rights reserved.
@@ -26,8 +27,6 @@
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#
-# $Id: dot.hdprofile,v 1.1 1995/10/27 22:39:43 deraadt Exp $
PATH=/sbin:/bin:/usr/bin:/usr/sbin:/
export PATH
@@ -57,6 +56,6 @@ if [ "X${DONEPROFILE}" = "X" ]; then
. /.commonutils
. /.instutils
- echo "Follow the installation directions to install the NetBSD"
+ echo "Follow the installation directions to install the OpenBSD"
echo "distribution sets."
fi
diff --git a/distrib/sparc/floppies/inst/dot.instutils b/distrib/sparc/floppies/inst/dot.instutils
index af22d774eff..496c10f1726 100644
--- a/distrib/sparc/floppies/inst/dot.instutils
+++ b/distrib/sparc/floppies/inst/dot.instutils
@@ -1,3 +1,4 @@
+# $OpenBSD: dot.instutils,v 1.2 1996/04/25 21:31:16 niklas Exp $
#
# Copyright (c) 1994 Christopher G. Demetriou
# All rights reserved.
@@ -26,12 +27,10 @@
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#
-# $Id: dot.instutils,v 1.1 1995/10/27 22:39:44 deraadt Exp $
-# Installation configuration utilites (functions), to get NetBSD configured
+# Installation configuration utilites (functions), to get OpenBSD configured
# reasonably once it is installed on the hard disk. These are meant to be
-# invoked from the shell prompt, by people installing NetBSD.
+# invoked from the shell prompt, by people installing OpenBSD.
Configure()
{
diff --git a/distrib/sparc/floppies/inst/install.sh b/distrib/sparc/floppies/inst/install.sh
index d450174c3de..4142d3b6042 100644
--- a/distrib/sparc/floppies/inst/install.sh
+++ b/distrib/sparc/floppies/inst/install.sh
@@ -1,4 +1,5 @@
#!/bin/sh
+# $OpenBSD: install.sh,v 1.2 1996/04/25 21:31:19 niklas Exp $
#
# Copyright (c) 1994 Christopher G. Demetriou
# All rights reserved.
@@ -27,10 +28,8 @@
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# $Id: install.sh,v 1.1 1995/10/27 22:39:49 deraadt Exp $
# NetBSD installation script.
# In a perfect world, this would be a nice C program, with a reasonable
# user interface.
@@ -48,9 +47,9 @@ getresp() {
fi
}
-echo "Welcome to the NetBSD ${VERSION} installation program."
+echo "Welcome to the OpenBSD ${VERSION} installation program."
echo ""
-echo "This program is designed to help you put NetBSD on your hard disk,"
+echo "This program is designed to help you put OpenBSD on your hard disk,"
echo "in a simple and rational way. You'll be asked several questions,"
echo "and it would probably be useful to have your disk's hardware"
echo "manual, the installation notes, and a calculator handy."
@@ -88,7 +87,7 @@ echo ""
echo "To do the installation, you'll need to provide some information about"
echo "your disk."
echo ""
-echo "NetBSD can be installed on ST506, ESDI, IDE, or SCSI disks."
+echo "OpenBSD can be installed on ST506, ESDI, IDE, or SCSI disks."
echo -n "What kind of disk will you be installing on? [SCSI] "
getresp "SCSI"
case "$resp" in
@@ -159,7 +158,7 @@ labelname=$resp
echo ""
echo "You will now need to provide some information about your disk's"
echo "geometry. This should either be in the User's Manual for your disk,"
-echo "or you should have written down what NetBSD printed when booting."
+echo "or you should have written down what OpenBSD printed when booting."
echo "(Note that he geometry that's printed at boot time is preferred.)"
echo ""
echo -n "Number of bytes per disk sector? [512] "
@@ -215,13 +214,13 @@ if [ $sizeunit = "sectors" ]; then
fi
echo -n ""
-echo -n "Size of NetBSD portion of disk (in $sizeunit)? "
+echo -n "Size of OpenBSD portion of disk (in $sizeunit)? "
getresp
partition=$resp
partition_sects=`expr $resp \* $sizemult`
part_offset=0
if [ $partition_sects -lt $disksize ]; then
- echo -n "Offset of NetBSD portion of disk (in $sizeunit)? "
+ echo -n "Offset of OpenBSD portion of disk (in $sizeunit)? "
getresp
part_offset=$resp
fi
@@ -264,7 +263,7 @@ echo ""
swap=0
while [ $swap -eq 0 ]; do
- echo "$units_left $sizeunit remaining in NetBSD portion of disk."
+ echo "$units_left $sizeunit remaining in OpenBSD portion of disk."
echo -n "Swap partition size (in $sizeunit)? "
getresp
case $resp in
@@ -287,7 +286,7 @@ blocksize=8192
$DONTDOIT mount -u /dev/fd0a /
cat /etc/disktab.preinstall > $DT
echo "" >> $DT
-echo "$labelname|NetBSD installation generated:\\" >> $DT
+echo "$labelname|OpenBSD installation generated:\\" >> $DT
echo " :dt=${type}:ty=winchester:\\" >> $DT
echo -n " :nc#${cyls_per_disk}:ns#${sects_per_track}" >> $DT
echo ":nt#${tracks_per_cyl}:\\" >> $DT
@@ -304,8 +303,8 @@ _offset=`expr $part_offset \* $sizemult`
echo " :pc#${_size}:oc#${_offset}:\\" >> $DT
echo "You will now have to enter information about any other partitions"
-echo "to be created in the NetBSD portion of the disk. This process will"
-echo "be complete when you've filled up all remaining space in the NetBSD"
+echo "to be created in the OpenBSD portion of the disk. This process will"
+echo "be complete when you've filled up all remaining space in the OpenBSD"
echo "portion of the disk."
while [ $part_used -lt $partition ]; do
@@ -313,7 +312,7 @@ while [ $part_used -lt $partition ]; do
units_left=`expr $partition - $part_used`
while [ $part_size -eq 0 ]; do
echo ""
- echo -n "$units_left $sizeunit remaining in NetBSD portion of "
+ echo -n "$units_left $sizeunit remaining in OpenBSD portion of "
echo "the disk"
echo -n "Next partition size (in $sizeunit)? "
getresp
@@ -373,7 +372,7 @@ sync
echo ""
echo "THIS IS YOUR LAST CHANCE!!!"
echo ""
-echo -n "Are you SURE you want NetBSD installed on your hard drive? (yes/no) "
+echo -n "Are you SURE you want OpenBSD installed on your hard drive? (yes/no) "
answer=""
while [ "$answer" = "" ]; do
getresp
@@ -469,10 +468,10 @@ echo "OK! The preliminary work of setting up your disk is now complete."
echo ""
echo "The remaining tasks are:"
echo ""
-echo "To copy a NetBSD kernel to the hard drive's root filesystem."
+echo "To copy a OpenBSD kernel to the hard drive's root filesystem."
echo "Once accomplished, you can boot off the hard drive."
echo ""
-echo "To load and install the NetBSD distribution sets."
+echo "To load and install the OpenBSD distribution sets."
echo "Currently the hard drive's root filesystem is mounted on /mnt"
echo ""
echo "Consult the installation notes which will describe how to"
@@ -27,10 +28,8 @@
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#
-# $Id: install.sh,v 1.1 1995/10/27 22:39:49 deraadt Exp $
-# NetBSD installation script.
+# OpenBSD installation script.
# In a perfect world, this would be a nice C program, with a reasonable
# user interface.